
Sample Project
===============
This is an example project that is used to demonstrate how to publish
Python packages on PyPI.

Installing
============

.. code-block:: bash

    pip install example-publish-pypi-

Usage
=====

